Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(390)

Unified Diff: net/url_request/url_request.h

Issue 10310124: Implement a ResourceThrottle for URL overriding in Chrome on Android. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: incorporated feedback Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/web_contents_delegate.cc ('k') | net/url_request/url_request.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/url_request/url_request.h
diff --git a/net/url_request/url_request.h b/net/url_request/url_request.h
index 1bae37da4a2c86e2c39df80cd0cdccc250be0137..54a11ea91036d470cba810738290d516d9cca299 100644
--- a/net/url_request/url_request.h
+++ b/net/url_request/url_request.h
@@ -537,6 +537,9 @@ class NET_EXPORT URLRequest : NON_EXPORTED_BASE(public base::NonThreadSafe),
// request.
void CancelWithSSLError(int error, const SSLInfo& ssl_info);
+ // Cancels the requests and sets the status to HANDLED_EXTERNALLY.
+ void CancelWithHandledExternallyStatus();
darin (slow to review) 2012/05/29 23:39:32 It looks like this may actually be moving in the w
+
// Read initiates an asynchronous read from the response, and must only
// be called after the OnResponseStarted callback is received with a
// successful status.
@@ -684,9 +687,9 @@ class NET_EXPORT URLRequest : NON_EXPORTED_BASE(public base::NonThreadSafe),
// been orphaned.
void OrphanJob();
- // Cancels the request and set the error and ssl info for this request to the
- // passed values.
- void DoCancel(int error, const SSLInfo& ssl_info);
+ // Cancels the request and set the status and ssl info for this request to
+ // the passed values.
+ void DoCancel(const URLRequestStatus& status, const SSLInfo& ssl_info);
// Notifies the network delegate that the request has been completed.
// This does not imply a successful completion. Also a canceled request is
« no previous file with comments | « content/public/browser/web_contents_delegate.cc ('k') | net/url_request/url_request.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698